summaryrefslogtreecommitdiffstats
path: root/src/sources/labelsource.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 20:48:23 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 20:48:23 +0000
commit383adc283801b6238d8acfc750890613a63f8060 (patch)
treeaf3a65389067c05263db2ef4551a541501422998 /src/sources/labelsource.h
parentda7847adb43726079c7a4be1f06acbebe0bdde57 (diff)
downloadkima-383adc283801b6238d8acfc750890613a63f8060.tar.gz
kima-383adc283801b6238d8acfc750890613a63f8060.zip
TQt4 port kima
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kima@1239290 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/sources/labelsource.h')
-rw-r--r--src/sources/labelsource.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/sources/labelsource.h b/src/sources/labelsource.h
index 1a50ae0..1242524 100644
--- a/src/sources/labelsource.h
+++ b/src/sources/labelsource.h
@@ -24,26 +24,26 @@
#include "triggeredsource.h"
#include "labelsourcePrefs.h"
-class QLabel;
+class TQLabel;
/**
* LabelSource displays its value on a configurable QLabel
* @author Ken Werner
*/
class LabelSource : public TriggeredSource{
- Q_OBJECT //macro which activates signals and slots (moc)
+ TQ_OBJECT //macro which activates signals and slots (tqmoc)
public:
/**
* Creates a new DefaultSource from the given File
*/
- LabelSource(QWidget* inParent);
+ LabelSource(TQWidget* inParent);
virtual ~LabelSource();
/**
* Returns the Label of this source that is displayed in the kicker
*/
- QWidget* getWidget();
+ TQWidget* getWidget();
/**
* fills the prefs gui with appropriate values
@@ -51,7 +51,7 @@ public:
virtual void updatePrefsGUI();
/**
* realizes the widget. that means, create the QLabel.
*/
virtual void realizeWidget();
@@ -59,7 +59,7 @@ protected slots:
/**
* updates the label
*/
- virtual void updateLabel(const QString& inValue);
+ virtual void updateLabel(const TQString& inValue);
/**
* Applies the prefs
@@ -86,17 +86,17 @@ protected:
/**
* Allows subclasses adding their own preferences using the addPrefs method
*/
- virtual void createSubPrefs(QWidget* inParent);
+ virtual void createSubPrefs(TQWidget* inParent);
/**
* Displays the content of that source
*/
- QLabel* mLabel;
+ TQLabel* mLabel;
/**
- * the parent of the label we are going to create
+ * the tqparent of the label we are going to create
*/
- QWidget* mParent;
+ TQWidget* mParent;
private:
/**
@@ -24,26 +24,26 @@
/**
- * LabelSource displays its value on a configurable QLabel
+ * LabelSource displays its value on a configurable TQLabel
* @author Ken Werner
*/
@@ -51,7 +51,7 @@ public:
virtual void updatePrefsGUI();
/**
- * realizes the widget. that means, create the QLabel.
+ * realizes the widget. that means, create the TQLabel.
*/
virtual void realizeWidget();